@@ -80,7 +80,7 @@ class H2OXGBoostClassifier(H2OXGBoost):
                  skipDrop=0.0,
                  dmatrixType="auto",
                  backend="auto",
-                 gpuId=0,
+                 gpuId=None,
                  interactionConstraints=None,
                  modelId=None,
                  nfolds=0,
@@ -109,6 +109,7 @@ class H2OXGBoostClassifier(H2OXGBoost):
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.classification.H2OXGBoostClassifier", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
