@@ -120,12 +120,14 @@ class H2ODeepLearningRegressor(H2ODeepLearning):
                  maxRuntimeSecs=0.0,
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.0,
-                 exportCheckpointsDir=None):
+                 exportCheckpointsDir=None,
+                 aucType="AUTO"):
         Initializer.load_sparkling_jar()
         super(H2ODeepLearning, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.regression.H2ODeepLearningRegressor", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
